==> libsfml_1.2.orig.tar.gz: libsfml-1.2.orig/src/SFML/Window/VideoModeSupport.hpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007 Laurent Gomila (laurent.gom@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef SFML_VIDEOMODESUPPORT_HPP
#define SFML_VIDEOMODESUPPORT_HPP

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/Config.hpp>


#if defined(SFML_SYSTEM_WINDOWS)

    #include <SFML/Window/Win32/VideoModeSupport.hpp>

#elif defined(SFML_SYSTEM_LINUX)

    #include <SFML/Window/Linux/VideoModeSupport.hpp>

#elif defined(SFML_SYSTEM_MACOS)

    #include <SFML/Window/OSX/VideoModeSupport.hpp>

#endif


#endif // SFML_VIDEOMODESUPPORT_HPP

==> libsfml_1.3.orig.tar.gz: libsfml-1.3.orig/src/SFML/Window/VideoModeSupport.hpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2008 Laurent Gomila (laurent.gom@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef SFML_VIDEOMODESUPPORT_HPP
#define SFML_VIDEOMODESUPPORT_HPP

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/Config.hpp>


#if defined(SFML_SYSTEM_WINDOWS)

    #include <SFML/Window/Win32/VideoModeSupport.hpp>

#elif defined(SFML_SYSTEM_LINUX)

    #include <SFML/Window/Linux/VideoModeSupport.hpp>

#elif defined(SFML_SYSTEM_MACOS)

    #include <SFML/Window/OSXCarbon/VideoModeSupport.hpp>

#endif


#endif // SFML_VIDEOMODESUPPORT_HPP
